#root{max-width:1280px;margin:0 auto;padding:2rem;text-align:center}
/*# sourceMappingURL=data:application/json;base64,ewogICJ2ZXJzaW9uIjogMywKICAic291cmNlcyI6IFsiLi4vLi4vLi4vanMvd2lkZ2V0LmNzcyJdLAogICJzb3VyY2VzQ29udGVudCI6IFsiI3Jvb3Qge1xuICBtYXgtd2lkdGg6IDEyODBweDtcbiAgbWFyZ2luOiAwIGF1dG87XG4gIHBhZGRpbmc6IDJyZW07XG4gIHRleHQtYWxpZ246IGNlbnRlcjtcbn1cbiJdLAogICJtYXBwaW5ncyI6ICJBQUFBLENBQUMsS0FDQyxVQUFXLE9BRGIsT0FFVSxFQUFFLEtBRlosUUFHVyxLQUNULFdBQVksTUFDZCIsCiAgIm5hbWVzIjogW10KfQo= */
